@@ -11,18 +11,6 @@ import os
 import io
 import boto3
 
-def buckets_dur(fila, field):
-    """
-    Calculation of duration ranges.
-    """
-    rangos = {'0 a 1': [0, 365], '1 a 3': [365, 365 * 3], '3 a 5': [365 * 3, 365 * 5],
-              '5 a 7': [365 * 5, 365 * 7], '7 a 10': [365 * 7, 365 * 10]}
-    for valor, value in rangos.items():
-        if fila[field] == 'NA' or fila[field] < 0 or pd.isna(fila[field]):
-            return np.nan
-        elif fila[field] in range(value[0], value[1]):
-            return valor
-    return 'Mayor a 10'
 
 def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfolioName, subGroup, portfolio_fields, mkt_value_prorrateo=None, add_rows=None):
 
@@ -80,10 +68,12 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Portafolio=Portafolio[Columnas351]
     Precia=Precia[Columnasprecia]
 
+
     Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'] = np.where(Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO']=="0","NA",Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'])
     Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'] = np.where(Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'].isnull(),"NA",Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'])
     Portafolio['NEMOTECNICO'] = np.where(Portafolio['NEMOTECNICO']=="0","NA",Portafolio['NEMOTECNICO'])
     Portafolio['NEMOTECNICO'] = np.where(Portafolio['NEMOTECNICO'].isnull(),"NA",Portafolio['NEMOTECNICO'])
+
     # AJUSTAR ESTA LINEA CUANDO LLEGUEN NOMBRES DE PORTAFOLIOS.
     # Quemamos codigo PORTFOLIO = PATRIMONIO.
     Portafolio['PORTAFOLIO'] = np.where(Portafolio['PORTAFOLIO']=="OBL-RETIRO","RENTAS_VITALICIAS",Portafolio['PORTAFOLIO'])
@@ -199,9 +189,6 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     # Completo días al venc. con NA.
     Portafolio=Portafolio.astype({'daysToMaturity':'float'})
 
-    # Agrego rango duración.
-    Portafolio['bucketDur'] = Portafolio.apply(lambda x: buckets_dur(x, 'daysToMaturity'), axis=1)
-
     # Reemplazo [NULL] con NaN.
     Portafolio = Portafolio.replace("[NULL]", np.nan)
     Portafolio = Portafolio.replace('NA', np.nan)
@@ -285,4 +272,8 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Portafolio['subGroup'] = subGroup
     Portafolio['portfolioName'] = portfolioName
 
+    # Ajuste YTM
+    Portafolio['yieldToMaturity'] = np.where(Portafolio['valuationMethod']==9, Portafolio['discountRate'], Portafolio['yieldToMaturity'])
+
+
     return Portafolio
